%The code replicates the results reported in Section 3.2, in particular the
%ranks of the G and Gbar matrices.
%The code requires gensys package by Sims (2002), rows.m, gmatrix.m, gmatrix_ss.m and mufun.m to work.



%% Case 1: identification from the 2nd order properties; the 13-parameter case 
%Form theta0 using values from An and Schorfheide (2007, Table 3)
tau = 2.0000;
beta = 0.9975;
nu = 0.1000;
phi= 53.6797;
pistar=1.0080^2; %note pistar is squared
psi1 = 1.5000;
psi2 = 0.1250;
rhor = 0.7500;
rhog = 0.9500;
rhoz = 0.9000;
sig2r= (.002^2)*(10^5);
sig2g= (.006^2)*(10^5);
sig2z=(.003^2)*(10^5);
theta0=[tau,beta,nu,phi,pistar,psi1,psi2,rhor,rhog,rhoz,sig2r,sig2g,sig2z];
n=10000;
w=2*pi*(-4999:1:4999)'/n; %form vector of Fourier frequencies for approximation of the integral in G
G=gmatrix(w,theta0); %compute the G matrix
r=rank(G); %check rank
disp('-------------------------------------------------------------------------------');
disp('-----Case 1: Identification from the 2nd order properties (13 parameters)----');
disp('The rank of G is');
r
disp('The number of zero eigenvalues is')
13-r
disp('The eigenvalues are:')
format('long')
real(eig(G))




%% Case 2: identification from the 2nd order properties, the 11-parameter
% case (kappa instead of nu,phi,pistar)
clear
tau = 2.0000;
beta = 0.9975;
nu = 0.1000;
phi= 53.6797;
pistar=1.0080^2; %note pistar is squared
psi1 = 1.5000;
psi2 = 0.1250;
rhor = 0.7500;
rhog = 0.9500;
rhoz = 0.9000;
sig2r= (.002^2)*(10^5);
sig2g= (.006^2)*(10^5);
sig2z=(.003^2)*(10^5);
kap=(tau*(1-nu))/(nu*phi*pistar); %kappa
theta0=[tau,beta,kap,psi1,psi2,rhor,rhog,rhoz,sig2r,sig2g,sig2z];
n=10000;
w=2*pi*(-4999:1:4999)'/n; %form vector of Fourier frequencies for approximation of the integral in G
G=gmatrix(w,theta0); %compute the G matrix
r=rank(G); %check rank
disp('-------------------------------------------------------------------------------');
disp('-----Case 2: Identification from the 2nd order properties (11 parameters: kappa instead of nu,phi,pistar)----');
disp('The rank of G is');
r
disp('The number of zero eigenvalues is')
11-r
disp('The eigenvalues are:')
format('long')
real(eig(G))
disp('-------------------------------------------------------------------------------');





%% Case 3: identification from both 1st and 2nd order properties (requires mufun.m to work).
clear
tau = 2.0000;
beta = 0.9975;
nu = 0.1000;
phi= 53.6797;
pistar=1.0080^2; %note pistar is squared
psi1 = 1.5000;
psi2 = 0.1250;
rhor = 0.7500;
rhog = 0.9500;
rhoz = 0.9000;
sig2r= (.002^2)*(10^5);
sig2g= (.006^2)*(10^5);
sig2z=(.003^2)*(10^5);
gamq=0.55; %note extra ss parameter
theta0=[tau,beta,nu,phi,pistar,psi1,psi2,rhor,rhog,rhoz,sig2r,sig2g,sig2z,gamq];
n=10000;
w=2*pi*(-4999:1:4999)'/n; %form vector of Fourier frequencies for approximation of the integral in G
Gbar=gmatrix_ss(w,theta0); %compute the G-bar matrix
r=rank(Gbar); %check rank
disp('-------------------------------------------------------------------------------');
disp('-----Case 3: Identification from the 1st and 2nd order properties----');
disp('The rank of Gbar is');
r
disp('The number of zero eigenvalues is')
14-r
disp('The eigenvalues are:')
format('long')
real(eig(Gbar))

