% This file illustrates the procedure of locating non-identification subsets 
% as described in Section 3.1

%% Initial set-up
tau = 2.0000;
beta = 0.9975;
nu = 0.1000;
phi= 53.6797;
pistar=1.0080^2;
psi1 = 1.5000;
psi2 = 0.1250;
rhor = 0.7500;
rhog = 0.9500;
rhoz = 0.9000;
sig2r= (.002^2)*(10^5);
sig2g= (.006^2)*(10^5);
sig2z=(.003^2)*(10^5);
theta0=[tau,beta,nu,phi,pistar,psi1,psi2,rhor,rhog,rhoz,sig2r,sig2g,sig2z];
n=10000;
w=2*pi*(-5000:1:5000)'/n;
G=gmatrix(w,theta0); %compute the full G matrix to be used to extract submatrices (Gs)
                     %corresponding to the considered subsets
tol=max(size(G))*eps(norm(G)); %set tolerance level for rank (MATLAB default based on G)
                     %For internal consistency it is important to use the same tolerance level for determining
                     %whether an eigenvalue is zero for all considered Gs matrices.
                     
                     
                     
%% 1-element subsets
G1=diag(G); %Gs for 1-element subsets
            %clearly, none are equal to zero, so we carry all of the parameters over into the next step.
            
            
%% 2-element subsets
index2=nchoosek([1:13],2);      %all possible subsets of two elements
rank2=zeros(length(index2),1);  %blanks
eigv2=zeros(2,length(index2));
%rank2nt=rank2;
G2=zeros(2,2,length(index2));

for k=1:length(index2)
    for i=1:2
        for j=1:2
    G2(i,j,k)=G(index2(k,i),index2(k,j)); %Extract the 2-element Gs from the G matrix
        end
    end

rank2(k,1)=rank(G2(:,:,k),tol);     %rank with imposed tol
%rank2nt(k,1)=rank(G2(:,:,k));       %rank with default tol
eigv2(:,k)=eig(G2(:,:,k));          %eigenvalues of each Gs
end
mine2=sort(min(eigv2));             %auxiliary: sort matrices in ascending order of smallest eigenvalue
for i=1:length(index2)
    indev2(i,1)=find(mine2(1,i)==min(eigv2)); %find indices for eigenvalues sorted in ascending order
end
for i=1:length(index2)
    seigv2(:,i)=eigv2(:,indev2(i,1));       %sort eigenvalues based on smallest eigenvalue
    parvecs2(i,:)=index2(indev2(i,1),:);    %provide corresponding indices
    rank2s(1,i)=rank2(indev2(i,1),1);       %%provide corresponding ranks
    %rank2nts(1,i)=rank2nt(indev2(i,1),1);
end
%normeigv2=seigv2./([mean(seigv2);mean(seigv2)]); %eigenvalues normalized by mean eigenvalue
%Label the subsets with parameter names:
parnames=['tau   ';'beta  ';'nu    ';'phi   ';'pibar2';'psi1  ';'psi2  ';'rhor  ';'rhog  ';'rhoz  ';'sig2r ';'sig2g ';'sig2z '];
for i=1:length(index2)
    tabname2(i,:)=[parnames(index2(indev2(i,1),1),:),parnames(index2(indev2(i,1),2),:)];
end
%Examining seigv2 and rank2s we get 3 non-identified subsets:
disp('2-element non-identified subsets:')
format('long')
disp('subvector 1:')
disp(tabname2(1,:))
disp('       ')
disp('eigenvalues:')
disp(real(seigv2(:,1)))
disp('subvector 2:')
disp(tabname2(2,:))
disp('       ')
disp('eigenvalues:')
disp(real(seigv2(:,2)))
disp('subvector 3:')
disp(tabname2(3,:))
disp('       ')
disp('eigenvalues:')
disp(real(seigv2(:,3)))



%% 3-element subsets
index3=nchoosek([1:13],3); %all subsets of three elements
                           %Note that we can now exclude all of the 3-element subsets containing the ones
                           %identified above as proper subsets:
elim_pool=[3,4;4,5;3,5];   %pairs to eliminate
index_temp=[];             %index of entries to remove
for i=1:length(index3)
       flag=0;
       for j=1:3
               if(isempty(find(index3(i,:)==elim_pool(j,1)))==0 & isempty(find(index3(i,:)==elim_pool(j,2)))==0)
                       flag=1; %set flag to 1 if entry is to be removed
               end
       end
       if(flag==1)
               index_temp=horzcat(index_temp,i); %collect those indices together
       end
end
index3(index_temp,:)=[]; %complete removal
%The rest of the code is exactly the same as in the 2-element case:
rank3=zeros(length(index3),1); %blanks
eigv3=zeros(3,length(index3));
%rank3nt=rank3;
G3=zeros(3,3,length(index3));
for k=1:length(index3)
    for i=1:3
        for j=1:3
    G3(i,j,k)=G(index3(k,i),index3(k,j));
        end
    end

rank3(k,1)=rank(G3(:,:,k),tol);
%rank3nt(k,1)=rank(G3(:,:,k));
eigv3(:,k)=eig(G3(:,:,k));
end
mine3=sort(min(eigv3));
indev3=zeros(length(index3),1);
for i=1:length(index3)   
    indev3(i,1)=find(mine3(1,i)==min(eigv3));
end
for i=1:length(index3)
    seigv3(:,i)=eigv3(:,indev3(i,1)); 
    parvecs3(i,:)=index3(indev3(i,1),:); 
    rank3s(1,i)=rank3(indev3(i,1),1);
    %rank3nts(1,i)=rank3nt(indev3(i,1),1);
end
%normeigv3=seigv3./([mean(seigv3);mean(seigv3);mean(seigv3)]); %eigenvalues normalized by mean eigenvalue
parnames=['tau   ';'beta  ';'nu    ';'phi   ';'pibar2';'psi1  ';'psi2  ';'rhor  ';'rhog  ';'rhoz  ';'sig2r ';'sig2g ';'sig2z '];
for i=1:length(index3)
    tabname3(i,:)=[parnames(index3(indev3(i,1),1),:),parnames(index3(indev3(i,1),2),:),parnames(index3(indev3(i,1),3),:)];
end
%Looking at seigv3 and rank3s we find no subsets with zero eigenvalue(s)




%% 4-element subsets
index4=nchoosek([1:13],4); %all subsets of 4 elements
%Again, remove the entries containing known sources of non-identification:
index_temp=[]; %blank index of entries to remove
for i=1:length(index4)
       flag=0;
       for j=1:3
               if(isempty(find(index4(i,:)==elim_pool(j,1)))==0 & isempty(find(index4(i,:)==elim_pool(j,2)))==0)
                       flag=1; %set flag to 1 if entry is to be removed
               end
       end
       if(flag==1)
               index_temp=horzcat(index_temp,i); %collect those indices together
       end
end
index4(index_temp,:)=[]; %complete removal
%The rest is the same:
rank4=zeros(length(index4),1);
eigv4=zeros(4,length(index4));
%rank4nt=rank4;
G4=zeros(4,4,length(index4));
for k=1:length(index4)
    for i=1:4
        for j=1:4
    G4(i,j,k)=G(index4(k,i),index4(k,j));
        end
    end

rank4(k,1)=rank(G4(:,:,k),tol);
%rank4nt(k,1)=rank(G4(:,:,k));
eigv4(:,k)=eig(G4(:,:,k));
end
mine4=sort(min(eigv4));
indev4=zeros(length(index4),1);
for i=1:length(index4)   
    indev4(i,1)=find(mine4(1,i)==min(eigv4)); %find indices for eigenvalues sorted in ascending order
end
for i=1:length(index4)
    seigv4(:,i)=eigv4(:,indev4(i,1)); %sort eigenvalues based on smallest eigenvalue
    parvecs4(i,:)=index4(indev4(i,1),:); 
    rank4s(1,i)=rank4(indev4(i,1),1);
    %rank4nts(1,i)=rank4nt(indev4(i,1),1);
end
%normeigv4=seigv4./([mean(seigv4);mean(seigv4);mean(seigv4);mean(seigv4)]); %eigenvalues normalized by mean eigenvalue
parnames=['tau   ';'beta  ';'nu    ';'phi   ';'pibar2';'psi1  ';'psi2  ';'rhor  ';'rhog  ';'rhoz  ';'sig2r ';'sig2g ';'sig2z '];
for i=1:length(index4)
    tabname4(i,:)=[parnames(index4(indev4(i,1),1),:),parnames(index4(indev4(i,1),2),:),parnames(index4(indev4(i,1),3),:),parnames(index4(indev4(i,1),4),:)];
end
%Eyeballing rank4s and seigv4 we find another non-identification subset:
disp('4-element non-identified subsets:')
format('long')
disp('subvector 1:')
disp(tabname4(1,:))
disp('       ')
disp('eigenvalues:')
disp(real(seigv4(:,1)))


%% subsets with more than 4 elements
%No more non-identification subsets were detected (one may keep copypasting
%the code with minor changes to verify).

