%This uses data in Ni_curves.mat to check if the spectrum stays constant
%along the non-identification curves (as in Tables 2 and 3). 
%Requires gensys package by Sims (2002) and specsol.m to work.
%NB: 1st row of the theta_dir1 matrix corresponds to the original theta0
%parameter vector.

load Ni_curves_data %load curve points

n=10000;
k=10; %no of points considered
w=2*pi*(0:1:4999)'/n; %set frequencies to check spectrum at
benchmark=specsol(theta_dir1(1,:),w); % benchmark - spectrum at theta0
maxdev_a1=zeros(k,16); %blanks
maxdev_r1=maxdev_a1;
maxdev_rr1=maxdev_a1;
maxdev_r2=maxdev_a1;
maxdev_a2=maxdev_a1;
maxdev_rr2=maxdev_a1;
windex=maxdev_a1;
%select points in each direction and pick out maximum absolute/relative deviations.
%direction 1:
theta1=theta_dir1([1445:1445:14450]'+1,:); %select ten equally space points along Direction 1
for i=1:k
    ad=abs(benchmark-specsol(theta1(i,:),w));
    rd=ad./abs(benchmark);
    maxdev_a1(i,:)=max(ad); %maximum absolute deviations
    maxdev_r1(i,:)=max(rd); %maximum relative deviations
    for j=1:16
     windex(i,j)=max(find(ad(:,j)==max(ad(:,j))));
     maxdev_rr1(i,j) = rd(windex(i,j),j); % maximum absolute deviations in relative form
    end %measure 2 converts maximum abs deviations in maxdev_a1 and converts them into relative 
end
%direction2:
theta2=theta_dir2([10197:10197:101970]'+1,:); %select ten equally space points along Direction 2
windex=zeros(k,16);
for i=1:k
    ad=abs(benchmark-specsol(theta2(i,:),w));
    rd=ad./abs(benchmark);
    maxdev_a2(i,:)=max(ad); %maximum absolute deviations
    maxdev_r2(i,:)=max(rd); %maximum relative deviations
    for j=1:16
     windex(i,j)=find(ad(:,j)==max(ad(:,j)));
     maxdev_rr2(i,j) = rd(windex(i,j),j); % maximum absolute deviations in relative form
    end %measure 2 converts maximum abs deviations in maxdev_a1 and converts them into relative 
end
format('short')
disp('Results: Table 2: Deviations of spectra across frequencies (direction 1)');
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp('                                       ')
disp('                  Maximum absolute deviations')
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp(maxdev_a1(:,[1,2,3,4,6,7,8,11,12,16]))
disp('                                       ')
disp('             Maximum absolute deviations in relative form')
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp(maxdev_rr1(:,[1,2,3,4,6,7,8,11,12,16]))
disp('                                       ')
disp('             Maximum relative deviations ')
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp(maxdev_r1(:,[1,2,3,4,6,7,8,11,12,16]))


%
disp('Results: Table 3: Deviations of spectra across frequencies (direction 2)');
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp('                                       ')
disp('                  Maximum absolute deviations')
disp(maxdev_a2(:,[1,2,3,4,6,7,8,11,12,16]))
disp('                                       ')
disp('              Maximum absolute deviations in relative form')
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp(maxdev_rr2(:,[1,2,3,4,6,7,8,11,12,16]))
disp('                                       ')

disp('             Maximum relative deviations ')
disp('              Spectral density matrix element number')
disp('    (1,1)      (2,1)     (3,1)     (4,1)     (2,2)     (3,2)     (4,2)     (3,3)     (4,3)     (4,4)')
disp(maxdev_r2(:,[1,2,3,4,6,7,8,11,12,16]))

