function res = mufun(ind)
%The function to compute the jacobian of the steady-state term miu
%(see Assumption 4).
%Input: 
        %row vector of indices indicating the subset of parameters used
        %(e.g. useful for implementing Corollary 3). 
        %Inputting a=[1:14] provides the jacobian for the computation of G-bar as in
        %Theorem 2. 
%Set parameter values:
tau = 2.0000;
beta=0.9975;
nu = 0.1000; 
phi= 53.6797;
pistar=1.0080^2;
psi1 = 1.5000;
psi2 = 0.1250;
rhor = 0.7500;
rhog = 0.9500;
rhoz = 0.9000;
sig2r= (.002^2)*(10^5);
sig2g= (.006^2)*(10^5);
sig2z=(.003^2)*(10^5);
gamq=0.55;
%Evaluate analytically derived jacobian for the steady-state term
mujac= [ 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,        0;
 0,                160000/beta^4, 0, 0, -80000/(beta^2*pistar^(1/2)), 0, 0, 0, 0, 0, 0, 0, 0,     -1600/beta^2;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0, -80000/(beta^2*pistar^(1/2)), 0, 0,                 80000/pistar, 0, 0, 0, 0, 0, 0, 0, 0, 800/pistar^(1/2);
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                            0, 0, 0,                            0, 0, 0, 0, 0, 0, 0, 0, 0,                0;
 0,                 -1600/beta^2, 0, 0,             800/pistar^(1/2), 0, 0, 0, 0, 0, 0, 0, 0,               17];
nt=length(ind); %determine dimension of the result
muterm=zeros(nt,nt); %blank 
for i=1:nt
    for j=1:nt
        muterm(i,j)=mujac(ind(i),ind(j)); %extract the jacobian (see (11) on p. 16)
    end
end
res = muterm;
end